Blake2bHash class

Constructors

Blake2bHash()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hash(Uint8List message, int offset, int len) → Uint8List
Creates a combined hash code for a number of objects.
override
hashHexString(String hex) → Uint8List
hashHexString2HexString(String hex) → String
hashUtf8String(String string) → Uint8List
hashUtf8String2HexString(String string) → String
hashWithDigestSize(int digestSize, Uint8List message) → Uint8List