Const class

Constructors

Const()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

blake2bIv → List<Int64>
final
blake2Sigma → List<List<int>>
final
blockLengthBytes → int
final
f0 → Int64
final
rounds → int
final